#
# spec file for package OpenSceneGraph
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _osg_so_nr	131
%define _opt_so_nr	20
%if 0%{?suse_version} > 1320 || (0%{?suse_version} == 1315 && 0%{?is_opensuse})
%bcond_without gdal
%else
%bcond_with gdal
%endif
Name:           OpenSceneGraph
Version:        3.4.1
Release:        lp150.1.4
Summary:        3D graphics toolkit
# NOTE: also SUSE-wxWidgets-3.0 http://trac.openscenegraph.org/projects/osg/attachment/wiki/Legal/LICENSE.txt
License:        LGPL-2.1
Group:          Productivity/Graphics/Other
Url:            http://openscenegraph.org/projects/osg
Source0:        https://github.com/openscenegraph/%{name}/archive/%{name}-%{version}.tar.gz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM 8e26ebd23ef9_Fixed_coverity_detected_defect_OOB_read.patch -- Fix out-of-bound-read, also required for the next patch to apply
Patch0:         8e26ebd23ef9_Fixed_coverity_detected_defect_OOB_read.patch
# PATCH-FIX-UPSTREAM 01c712e85195_Explicit_signed_char_declarations.patch -- compilation fix for e.g. ARM, PPC
Patch1:         01c712e85195_Explicit_signed_char_declarations.patch
BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  fltk-devel
BuildRequires:  freeglut-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  giflib-devel
BuildRequires:  libSDL-devel
BuildRequires:  libSDL2-devel
BuildRequires:  libjasper-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libtiff-devel
BuildRequires:  openal-soft-devel
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  wxWidgets-devel
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-fft-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtkglext-1.0)
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.35
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(xrandr)
%if %{with gdal}
BuildRequires:  pkgconfig(gdal)
%endif

%description
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL, freeing the developer from implementing and optimizing low
level graphics calls, and provides many additional utilities for
development of graphics applications.

%package -n libOpenSceneGraph%{_osg_so_nr}
Summary:        Shared libraries for OpenSceneGraph
Group:          System/Libraries
%if "%{_osg_so_nr}" == "130"
# try to cover up past mistakes
Obsoletes:      libOpenSceneGraph100
%endif

%description -n libOpenSceneGraph%{_osg_so_nr}
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains the shared libraries for OpenSceneGraph.

%package -n libOpenSceneGraph-devel
Summary:        OpenSceneGraph development files
Group:          Development/Libraries/C and C++
Requires:       libOpenSceneGraph%{_osg_so_nr} = %{version}
Requires:       libOpenThreads-devel = %{version}

%description -n libOpenSceneGraph-devel
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains the header and development files for
OpenSceneGraph.

%package -n libOpenThreads%{_opt_so_nr}
Summary:        Shared libraries for OpenSceneGraph
Group:          System/Libraries

%description -n libOpenThreads%{_opt_so_nr}
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains the shared libraries for OpenSceneGraph.

%package -n libOpenThreads-devel
Summary:        OpenSceneGraph development files
Group:          Development/Libraries/C and C++
Requires:       libOpenThreads%{_opt_so_nr} = %{version}

%description -n libOpenThreads-devel
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains the header and development files for
OpenSceneGraph.

%package plugins
Summary:        Plugins for OpenSceneGraph
Group:          Productivity/Graphics/Other

%description plugins
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains some plugins for OpenSceneGraph.

%package examples
Summary:        OpenSceneGraph example applications
Group:          Productivity/Graphics/Other

%description examples
The OpenSceneGraph is a graphics toolkit for the development of
graphic applications such as flight simulators, games, virtual
reality and scientific visualization. Based around the concept of a
scene graph, it provides an object-oriented framework on top of
OpenGL.

This package contains some example applications built with OpenSceneGraph

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch0 -p1
%patch1 -p1
for file in *.txt ChangeLog; do
	sed -i "s/\r//g" "$file"
done
chmod 644 *.txt ChangeLog

%build
%cmake \
	-DBUILD_OSG_EXAMPLES=ON \
	-DBUILD_OSG_PLUGINS=ON \
	-DBUILD_DOCUMENTATION=OFF \
	-DBUILD_OSG_WRAPPER=ON \
	-DBUILD_OSG_APPLICATIONS=ON \
	-DCMAKE_BUILD_TYPE=Release \
	-DDYNAMIC_OPENSCENEGRAPH=ON \
	-DDYNAMIC_OPENTHREADS=ON \
	-DDESIRED_QT_VERSION=5
make %{?_smp_mflags}

%install
%cmake_install
# example bins installed in share dir, not acceptable. Note, this will break
# when %%{_datadir}/OpenSceneGraph is also used for other stuff
mv %{buildroot}%{_datadir}/OpenSceneGraph \
   %{buildroot}%{_libdir}

%post -n libOpenSceneGraph%{_osg_so_nr} -p /sbin/ldconfig
%post -n libOpenThreads%{_opt_so_nr} -p /sbin/ldconfig
%postun -n libOpenSceneGraph%{_osg_so_nr} -p /sbin/ldconfig
%postun -n libOpenThreads%{_opt_so_nr} -p /sbin/ldconfig

%files
%doc AUTHORS.txt LICENSE.txt NEWS.txt README.txt ChangeLog
%{_bindir}/osg2cpp
%{_bindir}/osgarchive
%{_bindir}/osgconv
%{_bindir}/osgfilecache
%{_bindir}/osgversion
%{_bindir}/osgviewer
%{_bindir}/present3D

%files plugins
%{_libdir}/osgPlugins-%{version}/

%files -n libOpenSceneGraph%{_osg_so_nr}
%{_libdir}/libosg.so.*
%{_libdir}/libosgAnimation.so.*
%{_libdir}/libosgDB.so.*
%{_libdir}/libosgFX.so.*
%{_libdir}/libosgGA.so.*
%{_libdir}/libosgManipulator.so.*
%{_libdir}/libosgParticle.so.*
%{_libdir}/libosgShadow.so.*
%{_libdir}/libosgSim.so.*
%{_libdir}/libosgTerrain.so.*
%{_libdir}/libosgText.so.*
%{_libdir}/libosgUtil.so.*
%{_libdir}/libosgUI.so.*
%{_libdir}/libosgVolume.so.*
%{_libdir}/libosgViewer.so.*
%{_libdir}/libosgWidget.so.*
%{_libdir}/libosgPresentation.so.*
%{_libdir}/libosgQt.so.*

%files -n libOpenSceneGraph-devel
%{_includedir}/osg/
%{_includedir}/osgAnimation/
%{_includedir}/osgDB/
%{_includedir}/osgFX/
%{_includedir}/osgGA/
%{_includedir}/osgManipulator/
%{_includedir}/osgParticle/
%{_includedir}/osgShadow/
%{_includedir}/osgSim/
%{_includedir}/osgTerrain/
%{_includedir}/osgText/
%{_includedir}/osgUI/
%{_includedir}/osgUtil/
%{_includedir}/osgViewer/
%{_includedir}/osgVolume/
%{_includedir}/osgWidget/
%{_includedir}/osgQt/
%{_includedir}/osgPresentation/
%{_libdir}/libosg.so
%{_libdir}/libosgAnimation.so
%{_libdir}/libosgDB.so
%{_libdir}/libosgFX.so
%{_libdir}/libosgGA.so
%{_libdir}/libosgManipulator.so
%{_libdir}/libosgParticle.so
%{_libdir}/libosgShadow.so
%{_libdir}/libosgSim.so
%{_libdir}/libosgTerrain.so
%{_libdir}/libosgText.so
%{_libdir}/libosgUI.so
%{_libdir}/libosgUtil.so
%{_libdir}/libosgViewer.so
%{_libdir}/libosgVolume.so
%{_libdir}/libosgWidget.so
%{_libdir}/libosgPresentation.so
%{_libdir}/libosgQt.so
%{_libdir}/pkgconfig/openscenegraph.pc
%{_libdir}/pkgconfig/openscenegraph-osg*.pc

%files examples
%{_libdir}/OpenSceneGraph

%files -n libOpenThreads%{_opt_so_nr}
%{_libdir}/libOpenThreads.so.*

%files -n libOpenThreads-devel
%{_includedir}/OpenThreads/
%{_libdir}/libOpenThreads.so
%{_libdir}/pkgconfig/openthreads.pc

%changelog
* Wed Feb 14 2018 mimi.vx@gmail.com 
- update to 3.4.1
  * Improves to GLES support across platforms
  * Full support for osgText and on screen stats across all platfroms
  * Build fixes to allow compilation against recent
    3rd party depdendency changes
  * Range of runtime fixes
* Fri Dec 15 2017 crrodriguez@opensuse.org
- Switch to QT5, as QT4 is dead.
- Remove manual requires on -devel package.
* Sat Aug 19 2017 stefan.bruens@rwth-aachen.de
- Add 8e26ebd23ef9_Fixed_coverity_detected_defect_OOB_read.patch
  Fix out-of-bound-read, also required for the next patch to apply
- Add 01c712e85195_Explicit_signed_char_declarations.patch
  Fix compilation on architectures where char is unsigned
* Sat Feb  4 2017 jengelh@inai.de
- Trim description
* Tue Aug 23 2016 rpm@fthiessen.de
- Fixed source url, required for factory submission
* Sun Jul 31 2016 jengelh@inai.de
- Rectify shared library package name
* Sat May 21 2016 rpm@fthiessen.de
- Fixed BuildRequires (libjasper, and gdal).
* Tue Nov 24 2015 rpm@fthiessen.de
- Update to 3.4.0
- Removed OpenSceneGraph-gcc43.patch, not more needed
- Removed OpenSceneGraph-libgif6.patch, fixed upstream
* Wed Nov 18 2015 Rene.vanPaassen@gmail.com
- Removed OpenSceneGraph-giflib.patch, patched upstream
* Tue Nov 17 2015 Rene.vanPaassen@gmail.com
- Update to 3.2.3
- fixes building osgearth 2.7.0
* Wed Feb 11 2015 mpluskal@suse.com
- Update to 3.2.1:
  * no changelog provided by upstream
- Fix building with recent giflib (OpenSceneGraph-giflib.patch)
* Tue Jan  7 2014 bruno@ioda-net.ch
- update to 3.2.0 stable release
  see http://svn.openscenegraph.org/osg/OpenSceneGraph/tags/OpenSceneGraph-3.2.1-rc1/ChangeLog
- updated _opt_so_nr from 12 to 13
- packaging
  make verbose 1
  use C(XX)_FLAGS_RELEASE for applying optflags correctly
  fix some rpmlint warnings
- removed patches:
  * OpenSceneGraph-xine12.patch : merged upstream
- modified patches:
  * OpenSceneGraph-libgif6.patch : partially merged upstream
    First part redone against 3.2.0
* Thu Oct  3 2013 seife+obs@b1-systems.com
- libOpenThreads-devel does not have a huge dependency
* Wed Apr  3 2013 joop.boonen@opensuse.org
- Created OpenSceneGraph-libgif6.patch
  Used Raymond Wooninck kdelibs patch as a template
  https://git.reviewboard.kde.org/r/109478/
* Sun Sep  2 2012 thorstenb@flightgear.org
- Dropped gtk-glext install dependency for openSUSE factory
* Sun Sep  2 2012 thorstenb@flightgear.org
- Dropped gtk-glext dependency for openSUSE factory
- Removed obsolete openSUSE versions from spec file
* Mon Jul  2 2012 thorstenb@flightgear.org
- Patch to compile with libxine >= 1.2.0
* Sun Feb 19 2012 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Kill build-time dependency on XUL; it is nowhere referenced
- Remove illegal Obsoletes/Provides (see shlib pol.)
- Ensure pkgconfig symbols are generated
* Thu Sep  1 2011 highwaystar.ru@gmail.com
- update to 3.0.1
* Sat Jul  2 2011 jengelh@medozas.de
- Use %%_smp_mflags for parallel building
- Strip %%clean section (not needed on BS)
* Tue Apr 13 2010 toni@links2linux.de
- update to 2.8.3
- added docs
- added ffmpeg based plugins
- added gdal based plugins
- split-off viewers (FLTK, QT, SDL, WX) to keep dependencies smaller
- new sonames ==> libOpenSceneGraph65
* Tue Oct 27 2009 toni@links2linux.de
- update to 2.8.2
* Thu May 21 2009 toni@links2linux.de
- update to 2.8.1
* Fri Feb 13 2009 toni@links2linux.de
- update to 2.8.0
- new sonames ==> libOpenSceneGraph55
* Tue Oct  7 2008 toni@links2linux.de
- update to 2.6.1
- new sonames ==> libOpenSceneGraph48
* Fri Aug  8 2008 toni@links2linux.de
- update to 2.6.0
- new sonames ==> libOpenThreads11, libOpenSceneGraph44
* Mon May 12 2008 toni@links2linux.de
- update to 2.4.0
- new sonames ==> libOpenThreads10, libOpenSceneGraph35
* Sat Feb  2 2008 toni@links2linux.de
- initial version 2.2
